glia.widgets package
====================

Subpackages
-----------

.. toctree::

    glia.widgets.editor

Submodules
----------

glia.widgets.jupyter module
---------------------------

.. automodule:: glia.widgets.jupyter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: glia.widgets
    :members:
    :undoc-members:
    :show-inheritance:
